# TODO

## Python 3 & deps upgrades

- [] Upgrade Flask-WTF to 0.13 and fix metaclass error
- [] Ugrade flask-sqlalchemy and other SQLA releated deps
- [] Fix SQLA warnings
- [] Fix all tests (including skipped ones) under Python 3.6
- [] Fix issues reported by `pylint --py3k`

## Testing & QA

- [] Install `pytest-randomly` and fix errors
- [] Fix all JS issues detected by ESlint and enable check on CI

## Other

See: <https://github.com/abilian/abilian-core/projects/1>
